#!/bin/bash -e
#
# This script takes no inputs; it merely wgets into is.sci.gsfc.nasa.gov
# and retrieves the latest leapsec file for RT-STPS
#

# First, find out where we are
case $0 in
/*)  SHELLFILE=$0 ;;
./*)  SHELLFILE=${PWD}${0#.} ;;
../*) SHELLFILE=${PWD%/*}${0#..} ;;
*)  SHELLFILE=$(type -P "$0") ; if [ "${SHELLFILE:0:1}" != "/" ]; then SHELLFILE="${PWD}/$SHELLFILE" ; fi ;;
esac

# readlink -m makes sure SHELLDIR is a simple absolute path
SHELLDIR=`readlink -m "${SHELLFILE%/*}"`

# So RT-STPS home must be two levels above this directory
RTSTPS_HOME="$SHELLDIR/../.."

# Define variables here!
HOSTNAME="is.sci.gsfc.nasa.gov"
EXTERNAL="ancillary/temporal"
USERNAME="anonymous"
PASSWORD=""
scanlist="$RTSTPS_HOME/ftp_leapsec_ftp.txt"


# Script begins below:

# 1.) Use wget to download the HTTPS directory with latest leapsec files
echo "_________________________________________________________"
echo Getting https://$HOSTNAME/$EXTERNAL
wget -q --no-parent --directory-prefix=$RTSTPS_HOME -X /$EXTERNAL/* -r https://$HOSTNAME/$EXTERNAL/

# Do not continue if there was error
if [[ $? -ne 0 ]]; then
	echo "Error occurred during leapsec retrieval: $? . Aborting"
	rm -rf $RTSTPS_HOME/$HOSTNAME
	exit $?
fi

# 2) Determine the latest leapsec file and overwrite the existing leapsec file in RT-STPS
ls -1 $RTSTPS_HOME/$HOSTNAME/$EXTERNAL/ > $scanlist
LATEST_LEAPSEC=`cat "$scanlist" | grep -o "leapsec.*.dat" | sort | tail -n 1`
echo "Latest leapsec file is $LATEST_LEAPSEC"
echo "Updating $RTSTPS_HOME/leapsec.dat ..."
mv -f $RTSTPS_HOME/$HOSTNAME/$EXTERNAL/$LATEST_LEAPSEC $RTSTPS_HOME/leapsec.dat

# Remove the temporary files created
rm -rf $RTSTPS_HOME/$HOSTNAME
rm -f "$scanlist"
